#!/bin/bash

#
# start the full YOUnite stack
#

echo creating the younite network...
docker network create younite 2> /dev/null || true

echo setting hostname used to access docker containers...
[ -z "$YOUNITE_HOSTNAME" ] && export YOUNITE_HOSTNAME=local.younite.org
echo YOUNITE_HOSTNAME defined as $YOUNITE_HOSTNAME

echo determining host IP address...
export HOST_IP=$(docker run --rm busybox sh -c "ping -c1 host.docker.internal | grep bytes.from | awk '{print \$4}' | sed s/:$//")
[ -z "$HOST_IP" ] && export HOST_IP=$(docker run --rm --network=younite --add-host=host.docker.internal:host-gateway busybox sh -c "ping -c1 host.docker.internal | grep bytes.from | awk '{print \$4}' | sed s/:$//")
if [ -z "$HOST_IP" ]; then
        echo "There is a Docker network connectivity issue. May I suggest troubleshooting with the Docker Busybox container."
        exit 1
fi
echo HOST_IP is $HOST_IP

echo downloading Docker Compose files...
curl https://younite.us/attachments/docker-compose.yml --output docker-compose.yml
curl https://younite.us/attachments/docker-compose-notifications.yml --output docker-compose-notifications.yml

echo logging into ECR...
aws ecr get-login-password --region us-west-2 | docker login --username AWS --password-stdin 160909222919.dkr.ecr.us-west-2.amazonaws.com

./stop.sh

echo pulling latest images...
docker compose -f docker-compose-notifications.yml pull

echo starting the stack...
docker compose -f docker-compose-notifications.yml up -d younite-db younite-mb younite-api younite-keycloak younite-notification-service-db younite-notification-service younite-data-virtualization-service

echo sleeping for 60 seconds...
sleep 60

./wait-for-api.sh younite-api http://localhost:8080/health UP
./wait-for-api.sh younite-notification-service http://localhost:8082/actuator/health UP
./wait-for-api.sh younite-data-virtualization-service http://localhost:8084/actuator/health UP

./wait-for-ready.sh younite-api "Started listener for AR-Data"
./wait-for-ready.sh younite-notification-service "Started listener for Notification-Data"
./wait-for-ready.sh younite-data-virtualization-service "Started listener for AR-Assembly"

docker compose -f docker-compose-notifications.yml up -d younite-ui

echo "SUCCESS!"
