@ECHO OFF

REM
REM start the full YOUnite stack
REM

echo creating the younite network...
docker network create younite > nul 2> nul

echo setting hostname used to access docker containers...
if not defined YOUNITE_HOSTNAME (
    set YOUNITE_HOSTNAME=local.younite.org
)
echo YOUNITE_HOSTNAME defined as %YOUNITE_HOSTNAME%

echo determining host IP address...
>ip.tmp docker run --rm busybox sh -c "ping -c1 host.docker.internal | sed -nE 's/^PING[^(]+\(([^)]+)\).*/\1/p'"
set /p HOST_IP=<ip.tmp
echo HOST_IP is %HOST_IP%
del ip.tmp

echo downloading docker compose files...
curl https://younite.us/attachments/docker-compose.yml --output docker-compose.yml

echo logging into ECR...
aws ecr get-login-password --region us-west-2 | docker login --username AWS --password-stdin 160909222919.dkr.ecr.us-west-2.amazonaws.com

call stop.cmd

echo pulling latest images...
docker compose pull

echo starting elasticsearch and keycloak...
docker compose up -d younite-elastic younite-keycloak

echo sleeping for 30 seconds...
timeout 30

REM wait for elastic to be up
call wait-for-api.cmd younite-elastic https://opensearch:admin@localhost:9200/_cluster/health status || goto end

REM make sure the Open ID Connect configuration is accessible (Kibana needs this to configure itself)
call wait-for-api.cmd younite-keycloak http://localhost:8800/auth/realms/younite/.well-known/openid-configuration younite || goto end

echo starting kibana and logstash...

docker compose up -d younite-kibana younite-logstash

echo sleeping for 60 seconds...
timeout 60

REM wait for Kibana to be "green" (it actually reports a lot more information, but green is part of it)
call wait-for-api.cmd younite-kibana http://localhost:5601/api/status green || goto end

echo starting the rest of the stack...
docker compose up -d younite-db younite-mb younite-api younite-notification-service-db younite-notification-service younite-data-virtualization-service

echo sleeping for 60 seconds...
timeout 60

call wait-for-api.cmd younite-api http://localhost:8080/health UP || goto end
call wait-for-api.cmd younite-notification-service http://localhost:8082/actuator/health UP || goto end
call wait-for-api.cmd younite-data-virtualization-service http://localhost:8084/actuator/health UP || goto end

REM the API and notification service aren't truly "UP" until they have connected to the message bus - so check for that
call wait-for-ready.cmd younite-api "Started listener for AR-Data" || goto end
call wait-for-ready.cmd younite-notification-service "Started listener for Notification-Data" || goto end
call wait-for-ready.cmd younite-data-virtualization-service "Started listener for AR-Assembly" || goto end

docker compose up -d younite-ui

echo SUCCESS! The stack is ready to go.

:end
